@@ -17,6 +17,7 @@ from typing import (
     List,
     Literal,
     Optional,
+    Tuple,
     Union,
     cast,
 )
@@ -42,6 +43,7 @@ from ..utils import (
     convert_str_to_timestamp,
     load_plugins,
 )
+from ..utils.cftime_utils import infer_cmor_like_time_frequency
 from .mixin import TemplateMixin
 from .storage_backend import Metadata, MetadataType
 
@@ -160,7 +162,7 @@ class VarAttrRule(BaseModel):
 class StatRule(BaseModel):
     """How to apply statistics."""
 
-    stat: Literal["min", "max", "minmax", "range", "bbox"]
+    stat: Literal["min", "max", "minmax", "range", "bbox", "timedelta"]
     var: Optional[str] = None  # for numeric stats on a single var
     coords: Optional[Union[List[str], str]] = None  # for time range, etc.
     lat: Optional[str] = None  # convenience keys for bbox
@@ -255,23 +257,38 @@ class CrawlerSettings(BaseModel):
 class PathSpecs(BaseModel):
     """Implementation of the Directory reference syntax."""
 
-    dir_parts: List[str] = Field(default_factory=list)
-    file_parts: List[str] = Field(default_factory=list)
+    dir_parts: Optional[List[str]] = None
+    file_parts: Optional[List[str]] = None
     file_sep: str = "_"
 
-    def get_metadata_from_path(self, rel_path: Path) -> Dict[str, Any]:
-        """Read path encoded metadata from path specs."""
+    def _get_metadata_from_dir(
+        self, data: Dict[str, Any], rel_path: Path
+    ) -> None:
         dir_parts = rel_path.parent.parts
-        file_parts = rel_path.name.split(self.file_sep)
-        if len(dir_parts) == len(self.dir_parts):
-            data: Dict[str, Any] = dict(zip(self.dir_parts, dir_parts))
-        else:
+
+        if self.dir_parts and len(dir_parts) == len(self.dir_parts):
+            data.update(
+                {
+                    k: v
+                    for (k, v) in zip(self.dir_parts, dir_parts)
+                    if k not in data
+                }
+            )
+        elif self.dir_parts:
             raise MetadataCrawlerException(
                 (
                     f"Number of dir parts for {rel_path.parent} do not match "
                     f"- needs: {len(self.dir_parts)} has: {len(dir_parts)}"
                 )
             ) from None
+
+    def _get_metadata_from_filename(
+        self, data: Dict[str, Any], rel_path: Path
+    ) -> None:
+        if self.file_parts is None:
+            return
+        file_parts = rel_path.name.split(self.file_sep)
+        _parts: Dict[str, str] = {}
         if len(file_parts) == len(self.file_parts):
             _parts = dict(zip(self.file_parts, file_parts))
         elif (
@@ -285,8 +302,13 @@ class PathSpecs(BaseModel):
                     f"- needs: {len(self.file_parts)} has: {len(file_parts)})"
                 )
             )
-        _parts.setdefault("time", "fx")
         data.update({k: v for (k, v) in _parts.items() if k not in data})
+
+    def get_metadata_from_path(self, rel_path: Path) -> Dict[str, Any]:
+        """Read path encoded metadata from path specs."""
+        data: Dict[str, Any] = {}
+        self._get_metadata_from_dir(data, rel_path)
+        self._get_metadata_from_filename(data, rel_path)
         data.pop("_", None)
         return data
 
@@ -386,6 +408,11 @@ class DataSpecs(BaseModel):
                             out[facet] = arr.max()
                         else:
                             out[facet] = [arr.min(), arr.max()]
+                case "timedelta":
+                    coord = coords[0] if coords else None
+                    out[facet] = infer_cmor_like_time_frequency(
+                        dset, rule.var or coord
+                    )
 
     def extract_from_data(self, dset: xarray.Dataset) -> Dict[str, Any]:
         """Extract metadata from the data."""
@@ -399,7 +426,7 @@ class DataSpecs(BaseModel):
 class Datasets(BaseModel):
     """Definition of datasets that should be crawled."""
 
-    __pydantic_extra__: Dict[str, str] = Field(init=False)
+    __pydantic_extra__: Dict[str, Any] = Field(init=False)
     model_config = ConfigDict(extra="allow")
     root_path: str | Path
     drs_format: str = "freva"
@@ -609,7 +636,9 @@ class DRSConfig(BaseModel, TemplateMixin):
                 case "conditional":
                     _rule = textwrap.dedent(rule.condition or "").strip()
                     s_cond = self.render_templates(_rule, data)
-                    cond = eval(s_cond, {}, getattr(self, "_model_dict", {}))
+                    cond = eval(
+                        s_cond, {}, getattr(self, "_model_dict", {})
+                    )  # nosec
                     result = rule.true if cond else rule.false
                 case "lookup":
                     args = cast(List[str], self.render_templates(rule.tree, data))
@@ -627,7 +656,7 @@ class DRSConfig(BaseModel, TemplateMixin):
                         self.render_templates(_call, data),
                         {},
                         getattr(self, "_model_dict", {}),
-                    )
+                    )  # nosec
             if result:
                 inp.metadata[facet] = result
 
@@ -666,7 +695,7 @@ class DRSConfig(BaseModel, TemplateMixin):
 
     def max_directory_tree_level(
         self, search_dir: str | Path, drs_type: str
-    ) -> int:
+    ) -> Tuple[int, bool]:
         """Get the maximum level for descending into directories.
 
         When searching for files in a directory we can only traverse the directory
@@ -686,18 +715,19 @@ class DRSConfig(BaseModel, TemplateMixin):
         version = cast(
             str, self.dialect[standard].facets.get("version", "version")
         )
+        is_versioned = True
+        dir_parts = self.dialect[standard].path_specs.dir_parts or []
         try:
-            version_idx = self.dialect[standard].path_specs.dir_parts.index(
-                version
-            )
+            version_idx = dir_parts.index(version)
         except ValueError:
             # No version given
-            version_idx = len(self.dialect[standard].path_specs.dir_parts)
+            version_idx = len(dir_parts)
+            is_versioned = False
         if root_path == search_dir:
             current_pos = 0
         else:
             current_pos = len(search_dir.relative_to(root_path).parts)
-        return version_idx - current_pos
+        return version_idx - current_pos, is_versioned
 
     def is_complete(self, data: Dict[str, Any], standard: str) -> bool:
         """Check if all metadata that can be collected was collected."""
